#!/usr/bin/perl -w

# slate -- create a slate

# USER MODIFIABLE VALUES
my $image   = "/var/tmp/slate.0000.png";
my $xres    = 720;
my $yres    = 486;
my $bgcolor = "#000000";		# slate background color in hex (RRGGBB)
my $fgcolor = "#ffffff";		# slate text color in hex (RRGGBB)
my $company = "Degraf/Wahrman Inc.";	# your company name
my $show    = "?";
my $shot    = "?";
my $take    = "?";
my $td      = `logname`; chomp($td);
my $date    = `date`; chomp($date);
my $notes   = "";


sub HelpAndExit()
{
    print STDERR <<"EOF";
Usage: 
    slate [options]

Options:
    -show <showname>	- The name of the show, '$show' default
    -shot <shotname>	- The name of the shot, '$shot' default
    -take <takenum>	- The take number, '$take' default
    -td <username>	- The td's name, default is current user's login name
    -date <datestr>	- The date string, default is current date/time ($date)
    -notes <text>	- The notes. Default is no text. Several notes
    			  strings can be specified, for individual lines.
    -xres <width>       - The slate image width in pixels. Default $xres
    -yres <height>      - The slate image height in pixels. Default $yres
    -image <pathname>   - The output image pathname. Default is $image

Examples:
    slate -show HONDA -shot 4A -notes "Door touch ups" -notes "FINAL/approved"

EOF
    exit(0);
}

# MAIN
{
    # PARSE ARGUMENTS
    for ( $t=0; $t<=$#ARGV; $t++ )
    {
	if ( $ARGV[$t] eq "-help" ) { HelpAndExit(); }
	elsif ( $ARGV[$t] eq "-show" ) { $t++; $show = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-shot" ) { $t++; $shot = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-take" ) { $t++; $take = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-td"   ) { $t++; $td   = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-date" ) { $t++; $date = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-xres" ) { $t++; $xres = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-yres" ) { $t++; $yres = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-image") { $t++; $image = $ARGV[$t]; }
	elsif ( $ARGV[$t] eq "-notes") { $t++; $notes .= "$ARGV[$t]\n"; }
	else
	    { print STDERR "$0: unknown argument '$ARGV[$t]'\n"; exit(1); }
    }

    $notes =~ s/\n/\\n    /g;

    # First, create an image of specified size and bgcolor
    system("convert -size ${xres}x${yres} 'XC:$bgcolor' $image");

    # DRAW SLATE GRAPHICS
    #    White rhombuses scaled to image size.
    {
	# COORDS
	my $xscale = ( $xres / 1000.0 );
	my $yscale = ( $yres / 1000.0 );
	my $cmd = "mogrify -fill '$fgcolor' ";
	for ( $t=0; $t<1000; $t += 200 )
	{
	    my $x1 = $t;
	    my $x2 = $t + 100;
	    my $x3 = $t + 200;
	    my $x4 = $t + 100;
	    my $y1 = 100;
	    $cmd .= "-draw 'scale $xscale,$yscale polygon ".
	            "$x1,0 $x2,0 $x3,$y1 $x4,$y1' ";
	}
	$cmd .= $image;
	system($cmd);
    }

    # Draw company name large
    {
	my $xscale = 4 * ( $xres / 720.0 );
	my $yscale = 3 * ( $yres / 486.0 );
	my $x = ( 1 / 10 * $xres ) / $xscale;
	my $y = ( 1 / 4 * $yres ) / $yscale;
	system("mogrify -fill '$fgcolor' ".
		   "-draw 'scale $xscale,$yscale text $x,$y \"$company\"' $image");
    }

    # Draw show/shot/take/animator/date
    {
	my $cmd = "mogrify -fill '$fgcolor' ";
	my $xscale = 2 * ( $xres / 720.0 );
	my $yscale = 2 * ( $yres / 486.0 );
	my $x = ( 1 / 10 * $xres ) / $xscale;
	my $y = ( 2 / 5 * $yres ) / $yscale;
	$cmd .= "-draw 'scale $xscale,$yscale text $x,$y \"".
		"Show: $show\n".
		"Shot: $shot\n".
		"Take: $take\n".
		"TD: $td\n".
		"Date: $date\n".
		"Notes:\n".
		"    $notes";
	$cmd .= "\"' $image";
	system($cmd);
    }
}
exit(0);
